@@ -86,7 +86,9 @@ def _draw_person(res, shirt_type='blue') -> Dict:
     res['person_regression.face_regression.face_y1'] = head[1] - head_radius
     res['person_regression.face_regression.face_w'] = 2 * head_radius
     res['person_regression.face_regression.face_h'] = 2 * head_radius
-    res['person_regression.face_regression.facial_characteristics'] = ','.join(map(str, face_characteristics))
+    facial = np.zeros(3, dtype=np.bool)
+    facial[list(face_characteristics)] = True
+    res['person_regression.face_regression.facial_characteristics'] = facial
 
     offsets = np.random.randint(-2, 2, size=4)
     d = head_radius * 2
