@@ -7,7 +7,7 @@ from dnn_cool_synthetic_dataset.base import create_dataset
 
 def test_generation():
     n = 10
-    imgs, label_dicts = create_dataset(n)
-    plt.imshow(imgs[0])
+    label_dicts = create_dataset(n)
+    plt.imshow(label_dicts[0]['img'])
     plt.show()
-    pprint(label_dicts[0])
\ No newline at end of file
+    pprint(label_dicts[0])
